@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,6 +26,29 @@ class CccClient(AbstractClient):
     _service = 'ccc'
 
 
+    def AbortAgentCruiseDialingCampaign(self, request):
+        """停止座席巡航式外呼任务
+
+        :param request: Request instance for AbortAgentCruiseDialingCampaign.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.AbortAgentCruiseDialingCampaignRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.AbortAgentCruiseDialingCampaignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AbortAgentCruiseDialingCampaign", params, headers=headers)
+            response = json.loads(body)
+            model = models.AbortAgentCruiseDialingCampaignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def AbortPredictiveDialingCampaign(self, request):
         """停止预测式外呼任务
 
@@ -49,6 +72,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def BindNumberCallInInterface(self, request):
+        """绑定号码呼入回调接口
+
+        :param request: Request instance for BindNumberCallInInterface.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.BindNumberCallInInterfaceRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.BindNumberCallInInterfaceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("BindNumberCallInInterface", params, headers=headers)
+            response = json.loads(body)
+            model = models.BindNumberCallInInterfaceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def BindNumberCallOutSkillGroup(self, request):
         """绑定号码外呼技能组
 
@@ -95,6 +141,54 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ControlAIConversation(self, request):
+        """提供服务端控制机器人的功能
+
+        :param request: Request instance for ControlAIConversation.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ControlAIConversationRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ControlAIConversationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ControlAIConversation", params, headers=headers)
+            response = json.loads(body)
+            model = models.ControlAIConversationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateAIAgentCall(self, request):
+        """用于调用AI模型发起外呼通话，仅限自有电话号码使用，目前开通高级版座席**限时**免费体验。
+
+        发起通话前，请先确认您的AI模型是否兼容 OpenAI、Azure 或 Minimax 协议，并前往模型服务商网站获取相关鉴权信息。 具体功能说明请参考文档 [腾讯云联络中心AI通话平台](https://cloud.tencent.com/document/product/679/112100)。
+
+        :param request: Request instance for CreateAIAgentCall.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAIAgentCallRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAIAgentCallResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAIAgentCall", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAIAgentCallResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAICall(self, request):
         """用于调用AI模型发起外呼通话，仅限自有电话号码使用，目前开通高级版座席**限时**免费体验。
 
@@ -143,6 +237,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAgentCruiseDialingCampaign(self, request):
+        """座席巡航式外呼。
+
+        :param request: Request instance for CreateAgentCruiseDialingCampaign.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.CreateAgentCruiseDialingCampaignRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.CreateAgentCruiseDialingCampaignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAgentCruiseDialingCampaign", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAgentCruiseDialingCampaignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAutoCalloutTask(self, request):
         """创建自动外呼任务
 
@@ -190,7 +307,11 @@ class CccClient(AbstractClient):
 
 
     def CreateCallOutSession(self, request):
-        """创建外呼会话，当前仅支持双呼，即先使用平台号码呼出到坐席手机上，坐席接听后，然后再外呼用户，而且由于运营商频率限制，坐席手机号必须先加白名单，避免频控导致外呼失败。
+        """创建外呼会话，当前仅支持双呼，即先使用平台号码呼出到座席手机上，座席接听后，然后再外呼用户，而且由于运营商频率限制，座席手机号必须先加白名单，避免频控导致外呼失败。所以调用此接口前，下述操作均已完成
+        1. UserId 指定的座席已经[绑定手机号](https://cloud.tencent.com/document/product/679/76067#.E6.AD.A5.E9.AA.A42.EF.BC.9A.E5.AE.8C.E5.96.84.E8.B4.A6.E5.8F.B7.E4.BF.A1.E6.81.AF)
+        2. 座席绑定的手机号已经[申请并通过了外呼白名单](https://cloud.tencent.com/document/product/679/76744#.E6.93.8D.E4.BD.9C.E6.AD.A5.E9.AA.A4)
+        3. 当前座席侧只能呼叫其手机，所以 IsForceMobile 字段当前必须为 true
+        4. 被叫不要填当前 UserId 所绑定的手机号，否则会造成占线呼叫失败
 
         :param request: Request instance for CreateCallOutSession.
         :type request: :class:`tencentcloud.ccc.v20200210.models.CreateCallOutSessionRequest`
@@ -419,6 +540,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteCCCSkillGroup(self, request):
+        """删除技能组
+
+        :param request: Request instance for DeleteCCCSkillGroup.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DeleteCCCSkillGroupRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DeleteCCCSkillGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteCCCSkillGroup", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteCCCSkillGroupResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteExtension(self, request):
         """删除话机账号
 
@@ -488,6 +632,52 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAICallExtractResult(self, request):
+        """获取 AI 通话内容提取结果。
+
+        :param request: Request instance for DescribeAICallExtractResult.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAICallExtractResultRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAICallExtractResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAICallExtractResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAICallExtractResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeAILatency(self, request):
+        """获取 AI 时延信息
+
+        :param request: Request instance for DescribeAILatency.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAILatencyRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAILatencyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAILatency", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAILatencyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeActiveCarrierPrivilegeNumber(self, request):
         """查询生效运营商白名单规则
 
@@ -511,6 +701,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAgentCruiseDialingCampaign(self, request):
+        """查询 座席巡航式外呼任务
+
+        :param request: Request instance for DescribeAgentCruiseDialingCampaign.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeAgentCruiseDialingCampaignRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeAgentCruiseDialingCampaignResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAgentCruiseDialingCampaign", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAgentCruiseDialingCampaignResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAutoCalloutTask(self, request):
         """查询自动外呼任务详情
 
@@ -927,6 +1140,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeSessionDetail(self, request):
+        """获取通话详情
+
+        :param request: Request instance for DescribeSessionDetail.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeSessionDetailRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeSessionDetailResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeSessionDetail", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeSessionDetailResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeSkillGroupInfoList(self, request):
         """获取技能组信息列表
 
@@ -973,6 +1209,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeStaffStatusHistory(self, request):
+        """查询座席状态历史
+
+        :param request: Request instance for DescribeStaffStatusHistory.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusHistoryRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.DescribeStaffStatusHistoryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeStaffStatusHistory", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeStaffStatusHistoryResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeStaffStatusMetrics(self, request):
         """获取坐席实时状态统计指标
 
@@ -1111,6 +1370,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ForceMemberOffline(self, request):
+        """强制客服下线
+
+        :param request: Request instance for ForceMemberOffline.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.ForceMemberOfflineRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.ForceMemberOfflineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ForceMemberOffline", params, headers=headers)
+            response = json.loads(body)
+            model = models.ForceMemberOfflineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def HangUpCall(self, request):
         """挂断电话
 
@@ -1295,6 +1577,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestoreMemberOnline(self, request):
+        """恢复客服上线
+
+        :param request: Request instance for RestoreMemberOnline.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.RestoreMemberOnlineRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.RestoreMemberOnlineResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestoreMemberOnline", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestoreMemberOnlineResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ResumePredictiveDialingCampaign(self, request):
         """恢复预测式外呼任务
 
@@ -1341,6 +1646,29 @@ class CccClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def TransferToManual(self, request):
+        """特定场景下讲会话转接到人工坐席
+
+        :param request: Request instance for TransferToManual.
+        :type request: :class:`tencentcloud.ccc.v20200210.models.TransferToManualRequest`
+        :rtype: :class:`tencentcloud.ccc.v20200210.models.TransferToManualResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("TransferToManual", params, headers=headers)
+            response = json.loads(body)
+            model = models.TransferToManualResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UnbindNumberCallOutSkillGroup(self, request):
         """解绑号码外呼技能组
 
